----------------------------------------------------------------------------------
-- ********* Fleatiny-FPGA Blinky LED example module ***********
-- Very simple example of how to create a custom logic module using HDL
-- Following VHDL code describes an up-counter with a count range of 12.5 million.
-- Counter value is incremented by the external system clock (which is 25MHz on the 
-- fleaFPGA Uno) LED1 on FleaFPGA Uno will change state (ie on/off/on/etc), every time 
-- the counter value reaches 12.5 million and then the counter will reset back to zero, 
-- repeating the cycle
--
-- Please Note: This source code is provided as-is and is only intended to illustrate
-- how to implement a simple VHDL project using FleaFPGA Uno.
--
-- Creation Date: 5th November 2015
-- Author: Valentin Angelovski
--
----------------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.numeric_std.ALL;

entity blinky is

  port(
		clk: in  STD_LOGIC;
		blink_LED: BUFFER  STD_LOGIC);

END blinky;  
  
  
ARCHITECTURE behavior OF blinky IS

BEGIN
   PROCESS(clk)
      VARIABLE count :   INTEGER RANGE 0 TO 12_500_000;
 
   BEGIN
      IF(clk'EVENT AND clk = '1') THEN
         IF(count < 12_500_000) THEN
            count := count + 1;
         ELSE
		    count := 0;
            blink_LED <= NOT blink_LED;
         END IF;
      END IF;
   END PROCESS; 
 
 
end architecture;